<p align="center">
  <img src="https://avatars.githubusercontent.com/u/168782993?s=200&v=4">
</p>
  <h1 align="center">DoubleHelix</h1>

[![Build + Lint](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-build-lint.yml/badge.svg)](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-build-lint.yml)
[![Python Publish](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-publish.yml/badge.svg)](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-publish.yml/badge.svg)

[![PyInstaller release for Linux](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-pyinstaller-linux.yml/badge.svg)](https://github.com/DoubleHelixApp/Helix/actions/workflows/python-pyinstaller-linux.yml)
[![PyInstaller release for Windows](https://github.com/DoubleHelixApp/DoubleHelix/actions/workflows/python-pyinstaller-win.yml/badge.svg)](https://github.com/DoubleHelixApp/Helix/actions/workflows/python-pyinstaller-win.yml)

DoubleHelix is a tool to manipulate genomic data made for laymen. Still under heavy development. Don't expect anything working.

- [PyPI Package](https://pypi.org/project/doublehelix/)
- [Documentation](https://doublehelix.app/)
- [Telegram Channel](https://t.me/DoubleHelixApp) (administered by [DoubleHelix's own Telegram bot](https://github.com/DoubleHelixApp/DoubleHelix-Telegram-BOT))

### Install
The only currently supported way to install `DoubleHelix` is with a PyPI package.

```bash
sudo apt install libqt6waylandclient6 samtools tabix bcftools python-is-python3 -y # Only for Linux
python -m pip install doublehelix
helix
```

__NOTE__: See the [doc](https://doublehelix.app/) for more details.
